@@ -1,27 +1,15 @@
+// SPDX-License-Identifier: GPL-2.0
+
 /*
- * The code below came from Andi Kleen/Intel/SuSe mcelog code,
+ * The code below came from Andi Kleen/Intel/SUSE mcelog code,
  * released under GNU Public General License, v.2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-*/
+ */
 
-#include <string.h>
 #include <stdio.h>
+#include <string.h>
 
-#include "ras-mce-handler.h"
 #include "bitfield.h"
+#include "ras-mce-handler.h"
 
 /* See IA32 SDM Vol3B Table 16.4.1 */
 
@@ -82,7 +70,7 @@ void snb_decode_model(struct ras_events *ras, struct mce_event *e)
 {
 	struct mce_priv *mce = ras->mce_priv;
 	uint32_t mca = e->status & 0xffff;
-	unsigned rank0 = -1, rank1 = -1, chan;
+	unsigned int rank0 = -1, rank1 = -1, chan;
 
 	switch (e->bank) {
 	case 4:
@@ -113,7 +101,7 @@ void snb_decode_model(struct ras_events *ras, struct mce_event *e)
 
 	/* Ignore unless this is an corrected extended error from an iMC bank */
 	if (e->bank < 8 || e->bank > 11 || (e->status & MCI_STATUS_UC) ||
-		!test_prefix(7, e->status & 0xefff))
+	    !test_prefix(7, e->status & 0xefff))
 		return;
 
 	/*
@@ -138,43 +126,9 @@ void snb_decode_model(struct ras_events *ras, struct mce_event *e)
 	 */
 	if (rank0 >= 0 && rank1 >= 0)
 		mce_snprintf(e->mc_location, "ranks=%d and %d",
-				     rank0, rank1);
+			     rank0, rank1);
 	else if (rank0 >= 0)
 		mce_snprintf(e->mc_location, "rank=%d", rank0);
 	else
 		mce_snprintf(e->mc_location, "rank=%d", rank1);
 }
-
-#if 0
-/*
- * Sandy Bridge EP and EP4S processors (family 6, model 45) support additional
- * logging for corrected errors in the integrated memory controller (IMC)
- * banks. The mode is off by default, but can be enabled by setting the
- * "MemError Log Enable" * bit in MSR_ERROR_CONTROL (MSR 0x17f).
- * The documentation in the August 2012 edition of Intel's Software developer
- * manual has some minor errors because the worng version of table 16-16
- * "Intel IMC MC Error Codes for IA32_MCi_MISC (i= 8, 11)" was included.
- * Corrections are:
- *  Bit 62 is the "VALID" bit for the "first-device" bits in MISC and STATUS
- *  Bit 63 is the "VALID" bit for the "second-device" bits in MISC
- *  Bits 58:56 and 61:59 should be marked as "reserved".
- * There should also be a footnote explaining how the "failing rank" fields
- * can be converted to a DIMM number within a channel for systems with either
- * two or three DIMMs per channel.
- */
-static int failrank2dimm(unsigned failrank, int socket, int channel)
-{
-	switch (failrank) {
-	case 0: case 1: case 2: case 3:
-		return 0;
-	case 4: case 5:
-		return 1;
-	case 6: case 7:
-		if (get_memdimm(socket, channel, 2, 0))
-			return 2;
-		else
-			return 1;
-	}
-	return -1;
-}
-#endif
