@@ -1,27 +1,15 @@
+// SPDX-License-Identifier: GPL-2.0
+
 /*
- * The code below came from Andi Kleen/Intel/SuSe mcelog code,
+ * The code below came from Andi Kleen/Intel/SUSE mcelog code,
  * released under GNU Public General License, v.2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-*/
+ */
 
-#include <string.h>
 #include <stdio.h>
+#include <string.h>
 
-#include "ras-mce-handler.h"
 #include "bitfield.h"
+#include "ras-mce-handler.h"
 
 /* See IA32 SDM Vol3B Appendix E.4.1 ff */
 
@@ -39,7 +27,7 @@ static struct field tls_bus_status[] = {
 	SBITFIELD(16, "Parity error detected during FSB request phase"),
 	SBITFIELD(17, "Partity error detected on Core 0 request's address field"),
 	SBITFIELD(18, "Partity error detected on Core 1 request's address field"),
-	FIELD(19, NULL),
+	FIELD_NULL(19),
 	SBITFIELD(20, "Parity error on FSB response field detected"),
 	SBITFIELD(21, "FSB data parity error on inbound date detected"),
 	SBITFIELD(22, "Data parity error on data received from Core 0 detected"),
@@ -48,8 +36,8 @@ static struct field tls_bus_status[] = {
 	SBITFIELD(25, "Data ECC event to error on inbound data correctable or uncorrectable"),
 	SBITFIELD(26, "Pad logic detected a data strobe glitch or sequencing error"),
 	SBITFIELD(27, "Pad logic detected a request strobe glitch or sequencing error"),
-	FIELD(28, NULL),
-	FIELD(31, NULL),
+	FIELD_NULL(28),
+	FIELD_NULL(31),
 	{}
 };
 
@@ -105,6 +93,7 @@ static void tulsa_decode_bus(struct mce_event *e, uint64_t status)
 static void tulsa_decode_internal(struct mce_event *e, uint64_t status)
 {
 	uint32_t mca = (status >> 16) & 0xffff;
+
 	if ((mca & 0xfff0) == 0)
 		decode_bitfield(e, mca, tls_front_status);
 	else if ((mca & 0xf0ff) == 0)
