@@ -1,22 +1,19 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /*
  * Copyright (c) 2020, Ampere Computing LLC.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
  */
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdbool.h>
-#include "ras-record.h"
-#include "ras-logger.h"
-#include "ras-report.h"
-#include "ras-non-standard-handler.h"
+
 #include "non-standard-ampere.h"
+#include "ras-logger.h"
+#include "ras-non-standard-handler.h"
+#include "ras-report.h"
+#include "types.h"
 
 /*Armv8 RAS compicant Error Record(APEI and BMC Reporting) Payload Type 0*/
 static const char * const disp_payload0_err_reg_name[] = {
@@ -31,6 +28,7 @@ static const char * const disp_payload0_err_reg_name[] = {
 	"MISC2:",
 	"MISC3:",
 };
+
 /*PCIe AER Error Payload Type 1*/
 static const char * const disp_payload1_err_reg_name[] = {
 	"Error Type:",
@@ -86,7 +84,6 @@ static const char * const err_cpm_sub_type[] = {
 	"ARMv8 Core 1",
 };
 
-
 static const char * const err_mcu_sub_type[] = {
 	"ERR0",
 	"ERR1",
@@ -155,8 +152,6 @@ static char *err_smmu_sub_type(int etype)
 	return "unknown error";
 }
 
-
-
 static const char * const err_pcie_aer_sub_type[] = {
 	"Root Port",
 	"Device",
@@ -173,7 +168,6 @@ static char *err_peci_rasdp_sub_type(int etype)
 	return "unknown error";
 }
 
-
 static const char * const err_ocm_sub_type[] = {
 	"ERR0",
 	"ERR1",
@@ -327,7 +321,7 @@ static const struct amp_ras_type_info amp_payload_error_type[] = {
 
 /*get the error type name*/
 static const char *oem_type_name(const struct amp_ras_type_info *info,
-				uint8_t type_id)
+				 uint8_t type_id)
 {
 	const struct amp_ras_type_info *type = &info[0];
 
@@ -350,7 +344,7 @@ static const char *oem_subtype_name(const struct amp_ras_type_info *info,
 
 		if (type->id != type_id)
 			continue;
-		if (type->sub == NULL)
+		if (!type->sub)
 			return type->name;
 		if (sub_type_id >= type->sub_num)
 			return "unknown";
@@ -477,7 +471,7 @@ static void record_amp_data(struct ras_ns_ev_decoder *ev_decoder,
 }
 
 static int store_amp_err_data(struct ras_ns_ev_decoder *ev_decoder,
-				const char *name)
+			      const char *name)
 {
 	int rc;
 
@@ -502,37 +496,37 @@ static int store_amp_err_data(struct ras_ns_ev_decoder *ev_decoder,
 
 /*save all Ampere Specific Error Payload type 0 to sqlite3 database*/
 static void record_amp_payload0_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
+				    const char *type_str, const char *subtype_str,
 				const struct amp_payload0_type_sec *err)
 {
-	if (ev_decoder != NULL) {
+	if (ev_decoder) {
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD0_FIELD_TYPE, 0, type_str);
+				AMP_PAYLOAD0_FIELD_TYPE, 0, type_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD0_FIELD_SUB_TYPE, 0, subtype_str);
+				AMP_PAYLOAD0_FIELD_SUB_TYPE, 0, subtype_str);
 
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD0_FIELD_INS, INSTANCE(err->instance), NULL);
+				AMP_PAYLOAD0_FIELD_INS, INSTANCE(err->instance), NULL);
 
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD0_FIELD_SOCKET_NUM,
+				AMP_PAYLOAD0_FIELD_SOCKET_NUM,
 			SOCKET_NUM(err->instance), NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD0_FIELD_STATUS_REG, err->err_status, NULL);
+				AMP_PAYLOAD0_FIELD_STATUS_REG, err->err_status, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD0_FIELD_ADDR_REG,
+				AMP_PAYLOAD0_FIELD_ADDR_REG,
 			err->err_addr, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD0_FIELD_MISC0,
+				AMP_PAYLOAD0_FIELD_MISC0,
 			err->err_misc_0, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD0_FIELD_MISC1,
+				AMP_PAYLOAD0_FIELD_MISC1,
 			err->err_misc_1, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD0_FIELD_MISC2,
+				AMP_PAYLOAD0_FIELD_MISC2,
 			err->err_misc_2, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD0_FIELD_MISC3,
+				AMP_PAYLOAD0_FIELD_MISC3,
 			err->err_misc_3, NULL);
 		store_amp_err_data(ev_decoder, "amp_payload0_event_tab");
 	}
@@ -540,10 +534,10 @@ static void record_amp_payload0_err(struct ras_ns_ev_decoder *ev_decoder,
 
 /*save all Ampere Specific Error Payload type 1 to sqlite3 database*/
 static void record_amp_payload1_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
+				    const char *type_str, const char *subtype_str,
 				const struct amp_payload1_type_sec *err)
 {
-	if (ev_decoder != NULL) {
+	if (ev_decoder) {
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
 				AMP_PAYLOAD1_FIELD_TYPE, 0, type_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
@@ -590,45 +584,45 @@ static void record_amp_payload1_err(struct ras_ns_ev_decoder *ev_decoder,
 
 /*save all Ampere Specific Error Payload type 2 to sqlite3 database*/
 static void record_amp_payload2_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
-				const struct amp_payload2_type_sec *err)
+				    const char *type_str, const char *subtype_str,
+				    const struct amp_payload2_type_sec *err)
 {
-	if (ev_decoder != NULL) {
+	if (ev_decoder) {
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD2_FIELD_TYPE, 0, type_str);
+				AMP_PAYLOAD2_FIELD_TYPE, 0, type_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD2_FIELD_SUB_TYPE, 0, subtype_str);
+				AMP_PAYLOAD2_FIELD_SUB_TYPE, 0, subtype_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_INS, INSTANCE(err->instance), NULL);
+				AMP_PAYLOAD2_FIELD_INS, INSTANCE(err->instance), NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_SOCKET_NUM,
+				AMP_PAYLOAD2_FIELD_SOCKET_NUM,
 			SOCKET_NUM(err->instance), NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_CE_REPORT_REG,
+				AMP_PAYLOAD2_FIELD_CE_REPORT_REG,
 			err->ce_register, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_CE_LOACATION,
+				AMP_PAYLOAD2_FIELD_CE_LOACATION,
 			err->ce_location, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_CE_ADDR,
+				AMP_PAYLOAD2_FIELD_CE_ADDR,
 			err->ce_addr, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_UE_REPORT_REG,
+				AMP_PAYLOAD2_FIELD_UE_REPORT_REG,
 			err->ue_register, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_UE_LOCATION,
+				AMP_PAYLOAD2_FIELD_UE_LOCATION,
 			err->ue_location, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_UE_ADDR,
+				AMP_PAYLOAD2_FIELD_UE_ADDR,
 			err->ue_addr, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD2_FIELD_RESERVED1,
+				AMP_PAYLOAD2_FIELD_RESERVED1,
 			err->reserved1, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD2_FIELD_RESERVED2,
+				AMP_PAYLOAD2_FIELD_RESERVED2,
 			err->reserved2, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD2_FIELD_RESERVED3,
+				AMP_PAYLOAD2_FIELD_RESERVED3,
 			err->reserved3, NULL);
 		store_amp_err_data(ev_decoder, "amp_payload2_event_tab");
 	}
@@ -636,36 +630,36 @@ static void record_amp_payload2_err(struct ras_ns_ev_decoder *ev_decoder,
 
 /*save all Ampere Specific Error Payload type 3 to sqlite3 database*/
 static void record_amp_payload3_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
+				    const char *type_str, const char *subtype_str,
 				const struct amp_payload3_type_sec *err)
 {
-	if (ev_decoder != NULL) {
+	if (ev_decoder) {
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD3_FIELD_TYPE, 0, type_str);
+				AMP_PAYLOAD3_FIELD_TYPE, 0, type_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			AMP_PAYLOAD3_FIELD_SUB_TYPE, 0, subtype_str);
+				AMP_PAYLOAD3_FIELD_SUB_TYPE, 0, subtype_str);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD3_FIELD_INS, INSTANCE(err->instance), NULL);
+				AMP_PAYLOAD3_FIELD_INS, INSTANCE(err->instance), NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD3_FIELD_SOCKET_NUM,
+				AMP_PAYLOAD3_FIELD_SOCKET_NUM,
 			SOCKET_NUM(err->instance), NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA0,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA0,
 			err->fw_speci_data0, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA1,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA1,
 			err->fw_speci_data1, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA2,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA2,
 			err->fw_speci_data2, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA3,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA3,
 			err->fw_speci_data3, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA4,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA4,
 			err->fw_speci_data4, NULL);
 		record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_INT64,
-			AMP_PAYLOAD3_FIELD_FW_SPEC_DATA5,
+				AMP_PAYLOAD3_FIELD_FW_SPEC_DATA5,
 			err->fw_speci_data5, NULL);
 		store_amp_err_data(ev_decoder, "amp_payload3_event_tab");
 	}
@@ -676,35 +670,30 @@ static void record_amp_data(struct ras_ns_ev_decoder *ev_decoder,
 			    enum amp_oem_data_type data_type,
 			    int id, int64_t data, const char *text)
 {
-	return 0;
 }
 
 static void record_amp_payload0_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
-				const struct amp_payload0_type_sec *err)
+				    const char *type_str, const char *subtype_str,
+				    const struct amp_payload0_type_sec *err)
 {
-	return 0;
 }
 
 static void record_amp_payload1_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
-				const struct amp_payload1_type_sec *err)
+				    const char *type_str, const char *subtype_str,
+				    const struct amp_payload1_type_sec *err)
 {
-	return 0;
 }
 
 static void record_amp_payload2_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
-				const struct amp_payload2_type_sec *err)
+				    const char *type_str, const char *subtype_str,
+				    const struct amp_payload2_type_sec *err)
 {
-	return 0;
 }
 
 static void record_amp_payload3_err(struct ras_ns_ev_decoder *ev_decoder,
-				const char *type_str, const char *subtype_str,
-				const struct amp_payload3_type_sec *err)
+				    const char *type_str, const char *subtype_str,
+				    const struct amp_payload3_type_sec *err)
 {
-	return 0;
 }
 
 static int store_amp_err_data(struct ras_ns_ev_decoder *ev_decoder, char *name)
@@ -716,7 +705,7 @@ static int store_amp_err_data(struct ras_ns_ev_decoder *ev_decoder, char *name)
 /*decode ampere specific error payload type 0, the CPU's data is save*/
 /*to sqlite by ras-arm-handler, others are saved by this function.*/
 void decode_amp_payload0_err_regs(struct ras_ns_ev_decoder *ev_decoder,
-				struct trace_seq *s,
+				  struct trace_seq *s,
 				const struct amp_payload0_type_sec *err)
 {
 	char buf[AMP_PAYLOAD0_BUF_LEN];
@@ -747,8 +736,7 @@ void decode_amp_payload0_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 	p += snprintf(p, end - p, " 0x%x\n", INSTANCE(err->instance));
 
 	//display socket number
-	if ((TYPE(err->type) == 0) &&
-	    ((err->subtype == 0x01) || (err->subtype == 0x02))) {
+	if (!TYPE(err->type) && (err->subtype == 0x01 || err->subtype == 0x02)) {
 		core_num = INSTANCE(err->instance) * 2 + err->subtype - 1;
 		p += snprintf(p, end - p, " %s",
 			      disp_payload1_err_reg_name[i++]);
@@ -803,8 +791,8 @@ void decode_amp_payload0_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 
 /*decode ampere specific error payload type 1 and save to sqlite db*/
 static void decode_amp_payload1_err_regs(struct ras_ns_ev_decoder *ev_decoder,
-					struct trace_seq *s,
-					const struct amp_payload1_type_sec *err)
+					 struct trace_seq *s,
+					 const struct amp_payload1_type_sec *err)
 {
 	char buf[AMP_PAYLOAD0_BUF_LEN];
 	char *p = buf;
@@ -887,8 +875,8 @@ static void decode_amp_payload1_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 
 /*decode ampere specific error payload type 2 and save to sqlite db*/
 static void decode_amp_payload2_err_regs(struct ras_ns_ev_decoder *ev_decoder,
-					struct trace_seq *s,
-					const struct amp_payload2_type_sec *err)
+					 struct trace_seq *s,
+					 const struct amp_payload2_type_sec *err)
 {
 	char buf[AMP_PAYLOAD0_BUF_LEN];
 	char *p = buf;
@@ -903,7 +891,7 @@ static void decode_amp_payload2_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 		subtype_str = err_peci_rasdp_sub_type(err->subtype);
 	else
 		subtype_str  = oem_subtype_name(amp_payload_error_type,
-					       TYPE(err->type), err->subtype);
+						TYPE(err->type), err->subtype);
 	//display error type
 	p += snprintf(p, end - p, " %s", disp_payload2_err_reg_name[i++]);
 	p += snprintf(p, end - p, " %s\n", type_str);
@@ -972,8 +960,8 @@ static void decode_amp_payload2_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 
 /*decode ampere specific error payload type 3 and save to sqlite db*/
 static void decode_amp_payload3_err_regs(struct ras_ns_ev_decoder *ev_decoder,
-					struct trace_seq *s,
-					const struct amp_payload3_type_sec *err)
+					 struct trace_seq *s,
+					 const struct amp_payload3_type_sec *err)
 {
 	char buf[AMP_PAYLOAD0_BUF_LEN];
 	char *p = buf;
@@ -989,7 +977,6 @@ static void decode_amp_payload3_err_regs(struct ras_ns_ev_decoder *ev_decoder,
 	p += snprintf(p, end - p, " %s", disp_payload3_err_reg_name[i++]);
 	p += snprintf(p, end - p, " %s\n", type_str);
 
-
 	//display error subtype
 	p += snprintf(p, end - p, " %s", disp_payload3_err_reg_name[i++]);
 	p += snprintf(p, end - p, " %s\n", subtype_str);
@@ -1067,20 +1054,21 @@ static int decode_amp_oem_type_error(struct ras_events *ras,
 	} else if (payload_type == PAYLOAD_TYPE_3) {
 		db_tab = amp_payload3_event_tab;
 		id = AMP_PAYLOAD3_FIELD_TIMESTAMP;
-	} else
+	} else {
 		return -1;
+	}
 
 	if (!ev_decoder->stmt_dec_record) {
 		if (ras_mc_add_vendor_table(ras, &ev_decoder->stmt_dec_record,
 					    &db_tab) != SQLITE_OK) {
 			trace_seq_printf(s,
-					"create sql %s fail\n",
-					sqlite3_table_list[payload_type]);
+					 "create sql %s fail\n",
+					 sqlite3_table_list[payload_type]);
 			return -1;
 		}
 	}
 	record_amp_data(ev_decoder, AMP_OEM_DATA_TYPE_TEXT,
-			   id, 0, event->timestamp);
+			id, 0, event->timestamp);
 #endif
 
 	if (payload_type == PAYLOAD_TYPE_0) {
