@@ -1,28 +1,16 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
+
 /*
- * Copyright (C) 2013 Mauro Carvalho Chehab <mchehab+redhat@kernel.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-*/
+ * Copyright (C) 2013 Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
+ */
 
 #ifndef __RAS_MCE_HANDLER_H
 #define __RAS_MCE_HANDLER_H
 
 #include <stdint.h>
+#include <traceevent/event-parse.h>
 
 #include "ras-events.h"
-#include <traceevent/event-parse.h>
 
 enum cputype {
 	CPU_GENERIC,
@@ -53,6 +41,7 @@ enum cputype {
 	CPU_ICELAKE_DE,
 	CPU_TREMONT_D,
 	CPU_SAPPHIRERAPIDS,
+	CPU_EMERALDRAPIDS,
 };
 
 struct mce_event {
@@ -74,8 +63,13 @@ struct mce_event {
 	uint8_t		cpuvendor;
 	uint64_t        synd;   /* MCA_SYND MSR: only valid on SMCA systems */
 	uint64_t        ipid;   /* MCA_IPID MSR: only valid on SMCA systems */
+	uint64_t	ppin;
+	uint32_t	microcode;
+	int32_t		vdata_len;
+	const uint64_t	*vdata;
 
 	/* Parsed data */
+	char		frutext[17];
 	char		timestamp[64];
 	char		bank_name[64];
 	char		error_msg[4096];
@@ -97,8 +91,8 @@ struct mce_priv {
 };
 
 #define mce_snprintf(buf, fmt, arg...) do {			\
-	unsigned __n = strlen(buf);				\
-	unsigned __len = sizeof(buf) - __n;			\
+	unsigned int __n = strlen(buf);				\
+	unsigned int __len = sizeof(buf) - __n;			\
 	if (!__len)						\
 		break;						\
 	if (__n) {						\
@@ -110,13 +104,17 @@ struct mce_priv {
 } while (0)
 
 /* register and handling routines */
-int register_mce_handler(struct ras_events *ras, unsigned ncpus);
+int register_mce_handler(struct ras_events *ras, unsigned int ncpus);
 int ras_mce_event_handler(struct trace_seq *s,
 			  struct tep_record *record,
 			  struct tep_event *event, void *context);
 
 /* enables intel iMC logs */
-int set_intel_imc_log(enum cputype cputype, unsigned ncpus);
+int set_intel_imc_log(enum cputype cputype, unsigned int ncpus);
+
+/* Undertake AMD SMCA Error Decoding */
+void decode_smca_error(struct mce_event *e, struct mce_priv *m);
+void amd_decode_errcode(struct mce_event *e);
 
 /* Per-CPU-type decoders for Intel CPUs */
 void p4_decode_model(struct mce_event *e);
@@ -141,29 +139,29 @@ void decode_amd_errcode(struct mce_event *e);
 /* Software defined banks */
 #define MCE_EXTENDED_BANK	128
 
-#define MCI_THRESHOLD_OVER  (1ULL<<48)  /* threshold error count overflow */
+#define MCI_THRESHOLD_OVER  BIT_ULL(48)  /* threshold error count overflow */
 
-#define MCI_STATUS_VAL   (1ULL<<63)  /* valid error */
-#define MCI_STATUS_OVER  (1ULL<<62)  /* previous errors lost */
-#define MCI_STATUS_UC    (1ULL<<61)  /* uncorrected error */
-#define MCI_STATUS_EN    (1ULL<<60)  /* error enabled */
-#define MCI_STATUS_MISCV (1ULL<<59)  /* misc error reg. valid */
-#define MCI_STATUS_ADDRV (1ULL<<58)  /* addr reg. valid */
-#define MCI_STATUS_PCC   (1ULL<<57)  /* processor context corrupt */
-#define MCI_STATUS_S	 (1ULL<<56)  /* signalled */
-#define MCI_STATUS_AR	 (1ULL<<55)  /* action-required */
+#define MCI_STATUS_VAL   BIT_ULL(63)  /* valid error */
+#define MCI_STATUS_OVER  BIT_ULL(62)  /* previous errors lost */
+#define MCI_STATUS_UC    BIT_ULL(61)  /* uncorrected error */
+#define MCI_STATUS_EN    BIT_ULL(60)  /* error enabled */
+#define MCI_STATUS_MISCV BIT_ULL(59)  /* misc error reg. valid */
+#define MCI_STATUS_ADDRV BIT_ULL(58)  /* addr reg. valid */
+#define MCI_STATUS_PCC   BIT_ULL(57)  /* processor context corrupt */
+#define MCI_STATUS_S	 BIT_ULL(56)  /* signalled */
+#define MCI_STATUS_AR	 BIT_ULL(55)  /* action-required */
 
 /* AMD-specific bits */
-#define MCI_STATUS_TCC          (1ULL<<55)  /* Task context corrupt */
-#define MCI_STATUS_SYNDV        (1ULL<<53)  /* synd reg. valid */
+#define MCI_STATUS_TCC          BIT_ULL(55)  /* Task context corrupt */
+#define MCI_STATUS_SYNDV        BIT_ULL(53)  /* synd reg. valid */
 /* uncorrected error,deferred exception */
-#define MCI_STATUS_DEFERRED     (1ULL<<44)
-#define MCI_STATUS_POISON       (1ULL<<43)  /* access poisonous data */
+#define MCI_STATUS_DEFERRED     BIT_ULL(44)
+#define MCI_STATUS_POISON       BIT_ULL(43)  /* access poisonous data */
 
-#define MCG_STATUS_RIPV  (1ULL<<0)   /* restart ip valid */
-#define MCG_STATUS_EIPV  (1ULL<<1)   /* eip points to correct instruction */
-#define MCG_STATUS_MCIP  (1ULL<<2)   /* machine check in progress */
-#define MCG_STATUS_LMCE  (1ULL<<3)   /* local machine check signaled */
+#define MCG_STATUS_RIPV  BIT_ULL(0)   /* restart ip valid */
+#define MCG_STATUS_EIPV  BIT_ULL(1)   /* eip points to correct instruction */
+#define MCG_STATUS_MCIP  BIT_ULL(2)   /* machine check in progress */
+#define MCG_STATUS_LMCE  BIT_ULL(3)   /* local machine check signaled */
 
 /* Those functions are defined on per-cpu vendor C files */
 int parse_intel_event(struct ras_events *ras, struct mce_event *e);
